set more off
clear all
set scheme s2manual

use spdaily
tsset date

tsline price
graph export eps/chartPrices.eps, replace
graph export svg/chartPrices.svg, replace

sjlog using logs/chart, replace
tsline return, ttick(9498, tpos(in)) ttext(3470 9498 "Black Monday", orient(horiz))
sjlog close, replace
graph export eps/chart.eps, replace
graph export svg/chart.svg, replace

sjlog using logs/describe, replace
describe
sjlog close, replace

sjlog using logs/summarize, replace
summarize return, detail
sjlog close, replace

sjlog using logs/summarize2, replace
summarize return if date != td(19Oct1987), detail
sjlog close, replace

use spmonthly, clear
sjlog using logs/summarizeMonthly, replace
summarize return, detail
sjlog close, replace

use spdaily
sjlog using logs/hist, replace
histogram return, normal normopts(lcolor(gs13)) kdensity kdenopts(lcolor(black))
sjlog close, replace
graph export eps/Hist.eps, replace
graph export svg/Hist.svg, replace

sjlog using logs/hist2, replace
histogram return if newdate != td(19Oct1987), bin(100) normal normopts(lcolor(gs13)) kdensity kdenopts(lcolor(black))
sjlog close, replace
graph export eps/Hist2.eps, replace
graph export svg/Hist2.svg, replace

histogram return, name(HistDaily)
graph export eps/HistDaily.eps, replace
graph export svg/HistDaily.svg, replace

use spmonthly, clear
histogram return, name(HistMonthly)
graph export eps/HistMonthly.eps, replace
graph export svg/HistMonthly.svg, replace

*graph combine HistDaily HistMonthly

use spdaily
sjlog using logs/qqplot, replace
qnorm return, grid
sjlog close, replace
graph export eps/qnorm.eps, replace
graph export svg/qnorm.svg, replace

sjlog using logs/pplot, replace
pnorm return, grid
sjlog close, replace
graph export eps/pnorm.eps, replace
graph export svg/pnorm.svg, replace

sjlog using logs/sktest, replace
sktest return
sjlog close, replace

sjlog using logs/sktest2, replace
sktest return, noadjust
sjlog close, replace

sjlog using logs/swilk, replace
swilk return
sjlog close, replace

sjlog using logs/sfrancia, replace
sfrancia return
sjlog close, replace

* white-noise simulations
sjlog using logs/WN, replace
clear
set obs 1000
generate index = _n
* fix seed
set seed 1
generate wn1 = rnormal(0,1)
generate wn2 = rnormal(0,1)
generate wn3 = rnormal(0,1)
tsset index
sjlog close, replace

sjlog using logs/WNgraph, replace
tsline wn1 wn2 wn3
sjlog close, replace
graph export eps/WN.eps, replace
graph export svg/WN.svg, replace

* random walk simulations
sjlog using logs/RW, replace
generate rw1 = sum(wn1)
generate rw2 = sum(wn2)
generate rw3 = sum(wn3)
tsline rw1 rw2 rw3
sjlog close, replace
graph export eps/RW.eps, replace
graph export svg/RW.svg, replace

* stationarity tests
use spdaily, clear
sjlog using logs/ADFPrices, replace
dfuller logprice, lags(2) regress
sjlog close, replace

sjlog using logs/LogPrices, replace
tsset date
tsline logprice
sjlog close, replace
graph export eps/LogPrices.eps, replace
graph export svg/LogPrices.svg, replace

sjlog using logs/ADF, replace
tsset newdate
dfuller return, lags(2) regress
sjlog close, replace

sjlog using logs/dfgls, replace
dfgls return
sjlog close, replace

sjlog using logs/pperron, replace
pperron return
sjlog close, replace

* autocorrelation
sjlog using logs/corr, replace
corrgram return
sjlog close, replace

sjlog using logs/ac, replace
ac return
sjlog close, replace
graph export eps/ac.eps, replace
graph export svg/ac.svg, replace

sjlog using logs/pacregress, replace
regress return L.return L2.return L3.return L4.return L5.return
corrgram return, lags(5)
sjlog close, replace

sjlog using logs/pac, replace
pac return
sjlog close, replace
graph export eps/pac.eps, replace
graph export svg/pac.svg, replace

* heteroskedasticity
sjlog using logs/ch1returns2, replace
generate returns2 = return^2
tsset date
tsline returns2 if newdate != td(19Oct1987)
sjlog close, replace
graph export eps/Returns2.eps, replace
graph export svg/Returns2.svg, replace

tsset newdate
ac returns2, name(ac)
graph export eps/acReturns2.eps, replace
graph export svg/acReturns2.svg, replace
pac returns2, name(pac)
graph export eps/pacReturns2.eps, replace
graph export svg/pacReturns2.svg, replace
*graph combine ac pac

sjlog using logs/archlm, replace
regress return
estat archlm, lags(1 5 10)
sjlog close, replace

* heteroskedasticity monthly data
use spmonthly, clear
tsset time
generate returns2 = return^2
ac returns2, name(acmonthly)
graph export eps/acMonthlyReturns2.eps, replace
graph export svg/acMonthlyReturns2.svg, replace
pac returns2, name(pacmonthly)
graph export eps/pacMonthlyReturns2.eps, replace
graph export svg/pacMonthlyReturns2.svg, replace
*graph combine acmonthly pacmonthly

clear all
sjlog using logs/ImportDataCode, replace
import excel spdaily.xlsx, sheet("Data") firstrow clear
sjlog close, replace

sjlog using logs/ImportDataCode2, replace
import excel spdaily.xlsx, describe 
sjlog close, replace

*sjlog using logs/ImportDataCode3, replace
*import excel date prices using spdaily.xlsx
*sjlog close, replace

sjlog using logs/newvariable, replace
bcal create spdaily, from(date) generate(newdate) excludemissing(date) replace
tsset newdate
sjlog close, replace

sjlog using logs/newvariable2, replace
generate logprice = ln(price)
generate return = d.logprice
generate blackmonday = 0
replace blackmonday = 1 if date==td(19Oct1987)
sjlog close, replace

sjlog using logs/labels, replace
label variable date "calendar date"
label variable date "business date"
label variable open "open price"
label variable high "high price"
label variable low "low price"
label variable close "close price"
label variable volume "traded volume"
label variable price "adj close"
label variable logprice "logarithmic price"
label variable return "logarithmic return"
sjlog close, replace
