clear all
set more off
set scheme s2manual

* simulate AR
sjlog using logs/simulateAR, replace
set obs 1500
* fix the seed
set seed 1
generate time = _n
tsset time
* define parameters for simulation
scalar constant = 0.01
scalar AR = 0.9
* simulate the process
generate mynormal = rnormal()
* AR(0.9)
generate y = .
replace y = mynormal in 1
replace y = constant + AR*L.y + mynormal if time>1
label variable y "AR(0.9)"
sjlog close, replace

* AR(0.1)
scalar constant = 0.01
scalar AR = 0.1
generate y1 = .
replace y1 = mynormal in 1
replace y1 = constant + AR*L.y1 + mynormal if time>1
label variable y1 "AR(0.1)"

* AR(-0.9)
scalar constant = 0.01
scalar AR = -0.9
generate y2 = .
replace y2 = mynormal in 1
replace y2 = constant + AR*L.y2 + mynormal if time>1
label variable y2 "AR(-0.9)"

* AR(-0.1)
scalar constant = 0.01
scalar AR = -0.1
generate y3 = .
replace y3 = mynormal in 1
replace y3 = constant + AR*L.y3 + mynormal if time>1
label variable y3 "AR(-0.1)"

drop if _n < 500

tsline y, name(AR09)
graph export eps/AR09.eps, replace
graph export svg/AR09.svg, replace
tsline y1, name(AR01)
graph export eps/AR01.eps, replace
graph export svg/AR01.svg, replace
tsline y2, name(ARNeg09)
graph export eps/AR-09.eps, replace
graph export svg/AR-09.svg, replace
tsline y3, name(ARNeg01)
graph export eps/AR-01.eps, replace
graph export svg/AR-01.svg, replace
*graph combine AR09 AR01 ARNeg09 ARNeg01, cols(2)

* correlograms on simulated AR(0.9) data
sjlog using logs/corrgram_AR09, replace
corrgram y, lags(20)
ac y, lags(20) name(ACAR09)
pac y, lags(20) name(PACAR09)
sjlog close, replace

ac y, lags(20)
graph export eps/AC_AR09.eps, replace
graph export svg/AC_AR09.svg, replace
pac y, lags(20)
graph export eps/PAC_AR09.eps, replace
graph export svg/PAC_AR09.svg, replace
*graph combine ACAR09 PACAR09, cols(2)

* estimate AR(1) model on simulated AR(0.9) data
sjlog using logs/ResAR1, replace
arima y, ar(1)
predict res, residuals
sjlog close, replace

sjlog using logs/res_AR09, replace
corrgram res, lags(20)
sjlog close, replace

* correlograms on simulated AR(0.1) data
sjlog using logs/corrgram_ARNeg09, replace
corrgram y2, lags(20)
ac y2, lags(20) name(ACARNeg09)
pac y2, lags(20) name(PACARNeg09)
sjlog close, replace

ac y2, lags(20)
graph export eps/AC_ARNeg09.eps, replace
graph export svg/AC_ARNeg09.svg, replace
pac y2, lags(20)
graph export eps/PAC_ARNeg09.eps, replace
graph export svg/PAC_ARNeg09.svg, replace
*graph combine ACARNeg09 PACARNeg09, cols(2)

* estimate AR(1) model on simulated AR(0.1) data 
sjlog using logs/res_ARNeg09, replace
drop res
arima y2, ar(1)
predict res, residuals
corrgram res, lags(20)
sjlog close, replace

* simulate MA(0.9)
sjlog using logs/simulateMA, replace
clear all
set obs 1500

* fix the seed
set seed 1

generate time = _n
tsset time

*define parameters for simulation
scalar constant = 0.01
scalar MA = 0.9

* simulate the process
generate mynormal = rnormal()

* MA(0.9)
generate y = .
replace y = mynormal in 1
replace y = constant+MA*L.mynormal+mynormal if time>1
label variable y "MA(0.9)"
sjlog close, replace
* drop if time < 500 -- show this in book but do not run here;
* done later as -drop if _n < 500-

* simulate MA(0.1)
scalar MA = 0.1
generate y1 = .
replace y1 = mynormal in 1
replace y1 = constant+MA*L.mynormal+mynormal if time>1
label variable y1 "MA(0.1)"

* simulate MA(-0.9)
scalar MA = -0.9
generate y2 = .
replace y2 = mynormal in 1
replace y2 = constant+MA*L.mynormal+mynormal if time>1
label variable y2 "MA(-0.9)"

* simulate MA(-0.1)
scalar MA = -0.1
generate y3 = .
replace y3 = mynormal in 1
replace y3 = constant+MA*L.mynormal+mynormal if time>1
label variable y3 "MA(-0.1)"

drop if _n < 500
tsline y, name(MA09)
graph export eps/MA09.eps, replace
graph export svg/MA09.svg, replace
tsline y1, name(MA01)
graph export eps/MA01.eps, replace
graph export svg/MA01.svg, replace
tsline y2, name(MANeg09)
graph export eps/MA-09.eps, replace
graph export svg/MA-09.svg, replace
tsline y3, name(MANeg01)
graph export eps/MA-01.eps, replace
graph export svg/MA-01.svg, replace
*graph combine MA09 MA01 MANeg09 MANeg01, cols(2)
window manage close graph

* ac and pac for MA(0.9)
ac y, lags(20) name(ACMA09)
graph export eps/AC_MA09.eps, replace
graph export svg/AC_MA09.svg, replace
pac y, lags(20) name(PACMA09)
graph export eps/PAC_MA09.eps, replace
graph export svg/PAC_MA09.svg, replace
*graph combine ACMA09 PACMA09, cols(2)

* estimate MA(1) model on simulated MA(0.9) data
sjlog using logs/res_MA09, replace
arima y, ma(1)
predict res, residuals
corrgram res, lags(20)
sjlog close, replace

* ac and pac for MA(0.9)
ac y2, lags(20) name(ACMANeg09)
graph export eps/AC_MANeg09.eps, replace
graph export svg/AC_MANeg09.svg, replace
pac y2, lags(20) name(PACMANeg09)
graph export eps/PAC_MANeg09.eps, replace
graph export svg/PAC_MANeg09.svg, replace
*graph combine ACMANeg09 PACMANeg09, cols(2)

* estimate MA(1) model on simulated MA(0.9) data
sjlog using logs/res_MANeg09, replace
arima y2, ma(1)
predict res2, residuals
corrgram res2, lags(20)
sjlog close, replace

* simulate ARMA(-0.8,0.3) model
sjlog using logs/simulateARMA, replace
clear all
set obs 1500

* fix the seed
set seed 1
generate time=_n
tsset time

* define parameters for ARMA(-0.8,0.3) simulation
scalar constant = 0.01
scalar AR = -0.8
scalar MA = 0.3
generate mynormal = rnormal()
generate y = .
replace y = mynormal in 1
replace y = constant + AR*L.y + MA*L.mynormal + mynormal if time>1
label variable y "ARMA(-0.8,0.3)"
sjlog close, replace

* simulate ARMA(0.7,0.5) model
scalar AR = 0.7
scalar MA = 0.5
generate y1 = .
replace y1 = mynormal in 1
replace y1 = constant + AR*L.y1 + MA*L.mynormal + mynormal if time>1
label variable y1 "ARMA(0.7,0.5)"

drop if _n < 500

tsline y, name(ARMA)
graph export eps/ARMA_-0803.eps, replace
graph export svg/ARMA_-0803.svg, replace
tsline y1, name(ARMA1)
graph export eps/ARMA_0705.eps, replace
graph export svg/ARMA_0705.svg, replace
*graph combine ARMA ARMA1, cols(2)

* AC and PAC for ARMA(-0.8,0.3)
ac y, lags(20) name(ACy)
graph export eps/AC_ARMA_Neg0803.eps, replace
graph export svg/AC_ARMA_Neg0803.svg, replace
pac y, lags(20) name(PACy)
graph export eps/PAC_ARMA_Neg0803.eps, replace
graph export svg/PAC_ARMA_Neg0803.svg, replace
*graph combine ACy PACy, cols(2)

* AC and PAC for ARMA(0.7,0.5)
ac y1, lags(20) name(ACy1)
graph export eps/AC_ARMA_0705.eps, replace
graph export svg/AC_ARMA_0705.svg, replace
pac y1, lags(20) name(PACy1)
graph export eps/PAC_ARMA_0705.eps, replace
graph export svg/PAC_ARMA_0705.svg, replace
*graph combine ACy1 PACy1, cols(2)

* S&P 500 AC and PAC
use spdaily, clear
tsset newdate
ac return, lags(40) name(AC_sp500)
graph export eps/ch2_ac.eps, replace
graph export svg/ch2_ac.svg, replace

pac return, lags(40) name(PAC_sp500)
graph export eps/ch2_pac.eps, replace
graph export svg/ch2_pac.svg, replace
*graph combine AC PAC, cols(2)

* EUR USD AC and PAC
use eurusd
generate time = _n
tsset time
generate delta = d.EURUSD
ac delta, name(AC_eurusd)
graph export eps/AC_EURUSD.eps, replace
graph export svg/AC_EURUSD.svg, replace
pac delta, name(PAC_eurusd)
graph export eps/PAC_EURUSD.eps, replace
graph export svg/PAC_EURUSD.svg, replace
*graph combine AC PAC, cols(2)

* estimate ARMA(2,1) model on S&P 500
use spdaily, clear
sjlog using logs/ARMA21, replace
tsset newdate
arima return, ar(1/2) ma(1)
estimates store ARMA21
sjlog close, replace

* estimate ARMA(2,0)
sjlog using logs/ARMA20, replace
arima return, ar(1/2) nolog
estimates store ARMA20
sjlog close, replace

sjlog using logs/ARMA2120Comparison, replace
estimates stats ARMA21 ARMA20
sjlog close, replace

* obtain residuals
sjlog using logs/ResARMA20, replace
predict residuals, residuals
sjlog close, replace

ac residuals
graph export eps/AC_ResidualsARMA20.eps, replace
graph export svg/AC_ResidualsARMA20.svg, replace

* estimate ARMA(1,0)
sjlog using logs/ARMA10, replace
arima return, ar(1)
sjlog close, replace

predict residualsAR1, residuals
ac residualsAR1
graph export eps/AC_ResidualsARMA10.eps, replace
graph export svg/AC_ResidualsARMA10.svg, replace

* model comparison
sjlog using logs/ICSP, replace
arima return, ar(1) nolog
estimates store ARMA10
estimates stats ARMA20 ARMA10
sjlog close, replace

sjlog using logs/ICSP2, replace
estimates table ARMA20 ARMA10, stats(aic bic)
sjlog close, replace

sjlog using logs/LRtestSP, replace
lrtest ARMA20 ARMA10
sjlog close, replace

* estimate AR(2) with robust standard errors
sjlog using logs/ARIMA20Robust, replace
arima return, ar(1/2) vce(robust) nolog
estimates store ARMA20robust
sjlog close, replace

sjlog using logs/ARIMA20RobustComparison, replace
estimates table ARMA20 ARMA20robust, se p
sjlog close, replace

* estimate ARIMA(2,1,0) on log prices
sjlog using logs/ARMAPrice, replace
arima logprice, arima(2,1,0) nolog
sjlog close, replace

* postestimation
sjlog using logs/WntestSP, replace
arima return, ar(1/2) nolog
predict residualsAR2, residual
wntestq residualsAR2
sjlog close, replace

wntestb residualsAR2
graph export eps/wntestb.eps, replace
graph export svg/wntestb.svg, replace

sjlog using logs/WntestSB, replace
wntestb residualsAR2, table
sjlog close, replace

estat acplot
graph export eps/Estatac.eps, replace
graph export svg/Estatac.svg, replace

* simulate AR(0.9)
sjlog using logs/Estatac_sim, replace
clear all
set obs 1500
set seed 1
generate time = _n
tsset time
scalar constant = 0.01
scalar AR = 0.9
generate mynormal = rnormal()
generate y = .
replace y = mynormal in 1
replace y = constant + AR*L.y + mynormal if time>1
label variable y "AR(0.9)"
arima y, ar(1)
estat acplot
sjlog close, replace
graph export eps/Estatac_Sim.eps, replace
graph export svg/Estatac_Sim.svg, replace

* poestestimation
use spdaily, clear
sjlog using logs/roots, replace
tsset newdate
arima return, ar(1/2) nolog
estimates store ARMA20
estat aroots
sjlog close, replace
graph export eps/Roots.eps, replace
graph export svg/Roots.svg, replace

* impulse response function
sjlog using logs/IRF, replace
irf create AR2, set(myirf1, replace)
irf graph irf
sjlog close, replace
graph export eps/irf.eps, replace
graph export svg/irf.svg, replace

sjlog using logs/IRFTable, replace
irf table irf
sjlog close, replace

* adding a dummy variable
sjlog using logs/BlackMonday, replace
generate dummy = 0
replace dummy = 1 if date==td(19Oct1987)
sjlog close, replace

sjlog using logs/BlackMonday2, replace
generate dummybis = (date==td(19Oct1987))
sjlog close, replace

sjlog using logs/ARMA20_Dummy, replace
arima return dummy, ar(1/2) nolog
estimates store ARMA20Dummy
sjlog close, replace

sjlog using logs/ARMA20_NoBM, replace
arima return if date!=td(19Oct1987), ar(1/2) nolog
sjlog close, replace

sjlog using logs/ICSPDummy, replace
estimates table ARMA20 ARMA20Dummy, stats(aic bic)
sjlog close, replace

sjlog using logs/ICSPDummyLR, replace
lrtest ARMA20 ARMA20Dummy
sjlog close, replace

* Forecasting
sjlog using logs/ch2forecasts, replace
arima return, ar(1/2) nolog
predict forecasts, xb
tsset date
tsline return forecasts
sjlog close, replace
*lcolor() option used for shading in book
tsline return forecasts, lcolor(black gs12)
graph export eps/ForecastMean.eps, replace
graph export svg/ForecastMean.svg, replace
