clear all
set more off
set scheme s2manual

use index
sjlog using logs/ReturnPlots, replace
tsset date
tsline Dax30, tlabel(, format(%tdccYY)) name(Dax30)
tsline FTSE100, tlabel(, format(%tdccYY)) name(FTSE100)
tsline Nikkei225, tlabel(, format(%tdccYY)) name(Nikkei225)
tsline SP500, tlabel(, format(%tdccYY)) name(SP500)
graph combine Dax30 FTSE100 Nikkei225 SP500
sjlog close, replace
graph export eps/Returns.eps, replace
graph export svg/Returns.svg, replace

* Summary statistics
sjlog using logs/Des4series, replace
summarize Dax30 FTSE100 Nikkei225 SP500, detail
sjlog close, replace

* Charts AC
sjlog using logs/ch4acreturn, replace
ac Dax30, name(ACDax30)
ac FTSE100, name(ACFTSE100)
ac Nikkei225, name(ACNikkei225)
ac SP500, name(ACSP500)
graph combine ACDax30 ACFTSE100 ACNikkei225 ACSP500
sjlog close, replace
graph export eps/ACReturns.eps, replace
graph export svg/ACReturns.svg, replace

* scalar DVEC
sjlog using logs/DVECH2Constraints, replace
tsset newdate
* ARCH constraints
constraint 1 [L.ARCH]1_1 = [L.ARCH]2_1
constraint 2 [L.ARCH]1_1 = [L.ARCH]2_2
constraint 3 [L.ARCH]1_1 = [L.ARCH]3_1
constraint 4 [L.ARCH]1_1 = [L.ARCH]3_2
constraint 5 [L.ARCH]1_1 = [L.ARCH]3_3
constraint 6 [L.ARCH]1_1 = [L.ARCH]4_1
constraint 7 [L.ARCH]1_1 = [L.ARCH]4_2
constraint 8 [L.ARCH]1_1 = [L.ARCH]4_3
constraint 9 [L.ARCH]1_1 = [L.ARCH]4_4

* GARCH constraints
constraint 10 [L.GARCH]1_1 = [L.GARCH]2_1
constraint 11 [L.GARCH]1_1 = [L.GARCH]2_2
constraint 12 [L.GARCH]1_1 = [L.GARCH]3_1
constraint 13 [L.GARCH]1_1 = [L.GARCH]3_2
constraint 14 [L.GARCH]1_1 = [L.GARCH]3_3
constraint 15 [L.GARCH]1_1 = [L.GARCH]4_1
constraint 16 [L.GARCH]1_1 = [L.GARCH]4_2
constraint 17 [L.GARCH]1_1 = [L.GARCH]4_3
constraint 18 [L.GARCH]1_1 = [L.GARCH]4_4
sjlog close, replace

sjlog using logs/ScalarDVEC, replace
mgarch dvech (Dax30 = L.Dax30) (FTSE100 = L.FTSE100) (Nikkei225 = L.Nikkei225) (SP500 = L.SP500), arch(1) garch(1) constraints(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18) nolog
estimates store scalardvech
sjlog close, replace

sjlog using logs/DVEC, replace
matrix scalarparam = e(b)
mgarch dvech (Dax30 = L.Dax30) (FTSE100 = L.FTSE100) (Nikkei225 = L.Nikkei225) (SP500 = L.SP500), arch(1) garch(1) from(scalarparam) nolog
estimates store dvech
sjlog close, replace

sjlog using logs/Dvechcomparison, replace
estimates stats scalardvech dvech
sjlog close, replace

* variances
sjlog using logs/DvechVariances, replace
predict H_dvech*, variance
tsset date
tsline H_dvech_Dax30_Dax30, tlabel(, format(%tdccYY)) name(H_dvech_VolDax30)
tsline H_dvech_FTSE100_FTSE100, tlabel(, format(%tdccYY)) name(H_dvech_VolFTSE100)
tsline H_dvech_Nikkei225_Nikkei225, tlabel(, format(%tdccYY)) name(H_dvech_VolNikkei225)
tsline H_dvech_SP500_SP500, tlabel(, format(%tdccYY)) name(H_dvech_VolSP500)
graph combine H_dvech_VolDax30 H_dvech_VolFTSE100 H_dvech_VolNikkei225 H_dvech_VolSP500
sjlog close, replace
graph export eps/VariancesDVECH.eps, replace
graph export svg/VariancesDVECH.svg, replace

* correlations
sjlog using logs/DvechCorrelations, replace
generate corr_dvech_daxsp = H_dvech_SP500_Dax30/((H_dvech_Dax30_Dax30)^0.5*(H_dvech_SP500_SP500)^0.5)
generate corr_dvech_ftsesp = H_dvech_SP500_FTSE100/((H_dvech_FTSE100_FTSE100)^0.5*(H_dvech_SP500_SP500)^0.5)
generate corr_dvech_nikkeisp = H_dvech_SP500_Nikkei225/((H_dvech_Nikkei225_Nikkei225)^0.5*(H_dvech_SP500_SP500)^0.5)
tsline corr_dvech_daxsp, tlabel(, format(%tdccYY)) name(corr_dvech_daxsp)
tsline corr_dvech_ftsesp, tlabel(, format(%tdccYY)) name(corr_dvech_ftsesp)
tsline corr_dvech_nikkeisp, tlabel(, format(%tdccYY)) name(corr_dvech_nikkeisp)
graph combine corr_dvech_daxsp corr_dvech_ftsesp corr_dvech_nikkeisp
sjlog close, replace
graph export eps/CorrelationsDVECH.eps, replace
graph export svg/CorrelationsDVECH.svg, replace

* CCC
sjlog using logs/CCC, replace
tsset newdate
mgarch ccc (Dax30 FTSE100 Nikkei225 SP500 = L.Dax30 L.FTSE100 L.Nikkei225 L.SP500), arch(1) garch(1) nolog
sjlog close, replace

sjlog using logs/CCCRestricted, replace
mgarch ccc (Dax30 = L.Dax30 L.FTSE100 L.SP500) (FTSE100 = L.Dax30 L.FTSE100 L.Nikkei225 L.SP500) (Nikkei225 =L.Dax30 L.FTSE100 L.Nikkei225 L.SP500) (SP500 = L.Dax30 L.SP500), arch(1) garch(1) nolog
sjlog close, replace

sjlog using logs/CCCRestricted2, replace
mgarch ccc (Dax30 = L.Dax30 L.FTSE100 L.SP500, arch(1) garch(1)) (FTSE100 = L.Dax30 L.FTSE100 L.Nikkei225 L.SP500, arch(1/2) garch(1)) (Nikkei225 =L.Dax30 L.FTSE100 L.Nikkei225 L.SP500, arch(1) garch(1/2)) (SP500 = L.Dax30 L.SP500, arch(1) garch(1)), nolog
estimates store CCC
sjlog close, replace

* graph on variances
sjlog using logs/VariancesCCC, replace
predict H*, variance
tsset date
tsline H_Dax30_Dax30, tlabel(, format(%tdccYY)) name(VolDax30)
tsline H_FTSE100_FTSE100, tlabel(, format(%tdccYY)) name(VolFTSE100)
tsline H_Nikkei225_Nikkei225, tlabel(, format(%tdccYY)) name(VolNikkei225)
tsline H_SP500_SP500, tlabel(, format(%tdccYY)) name(VolSP500)
graph combine VolDax30 VolFTSE100 VolNikkei225 VolSP500
sjlog close, replace
graph export eps/VariancesCCC.eps, replace
graph export svg/VariancesCCC.svg, replace

* graph on correlations
sjlog using logs/CCCcorrelation, replace
predict corr*, correlation
tsline corr_FTSE100_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrftsedax)
tsline corr_Nikkei225_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrnikkeidax)
tsline corr_SP500_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrspdax)
tsline corr_Nikkei225_FTSE100, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrnikkeiftse)
tsline corr_SP500_FTSE100, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrspftse)
tsline corr_SP500_Nikkei225, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrspnikkei)
graph combine corrftsedax corrnikkeidax corrspdax corrnikkeiftse corrspftse corrspnikkei
sjlog close, replace
graph export eps/CorrelationsCCC.eps, replace
graph export svg/CorrelationsCCC.svg, replace

* DCC
sjlog using logs/DCC, replace
tsset newdate
mgarch dcc (Dax30 FTSE100 Nikkei225 SP500 = L.Dax30 L.FTSE100 L.Nikkei225 L.SP500), arch(1) garch(1) nolog
estimates store DCC
sjlog close, replace

sjlog using logs/LRTest_DCCCC, replace
lrtest CCC DCC
sjlog close, replace

sjlog using logs/CCCDCCcomparison, replace
estimates stats CCC DCC
sjlog close, replace

sjlog using logs/VariancesDCC, replace
tsset date
predict H_DCC*, variance
tsline H_DCC_Dax30_Dax30, tlabel(, format(%tdccYY)) name(VolDCCDax30)
tsline H_DCC_FTSE100_FTSE100, tlabel(, format(%tdccYY)) name(VolDCCFTSE100)
tsline H_DCC_Nikkei225_Nikkei225, tlabel(, format(%tdccYY)) name(VolDCCNikkei225)
tsline H_DCC_SP500_SP500, tlabel(, format(%tdccYY)) name(VolDCCSP500)
graph combine VolDCCDax30 VolDCCFTSE100 VolDCCNikkei225 VolDCCSP500
sjlog close, replace
graph export eps/VariancesDCC.eps, replace
graph export svg/VariancesDCC.svg, replace

sjlog using logs/CorrelationsDCC, replace
predict corr_DCC*, correlation
tsline corr_DCC_FTSE100_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdccftsedax)
tsline corr_DCC_Nikkei225_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdccnikkeidax)
tsline corr_DCC_SP500_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdccspdax)
tsline corr_DCC_Nikkei225_FTSE100, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdccnikkeiftse)
tsline corr_DCC_SP500_FTSE100, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdccspftse)
tsline corr_DCC_SP500_Nikkei225, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdccspnikkei)
graph combine corrdccftsedax corrdccnikkeidax corrdccspdax corrdccnikkeiftse corrdccspftse corrdccspnikkei
sjlog close, replace
graph export eps/CorrelationsDCC.eps, replace
graph export svg/CorrelationsDCC.svg, replace

* DCC postestimation
sjlog using logs/DCCArchTest, replace
tsset newdate
predict res*, residuals
predict var*, variance
generate stdresDax = res_Dax30/var_Dax30_Dax30^0.5
generate stdresSP500 = res_SP500/var_SP500_SP500^0.5
generate stdresNikkei225 = res_Nikkei225/var_Nikkei225_Nikkei225^0.5
generate stdresFtse = res_FTSE100/var_FTSE100_FTSE100 ^0.5
regress stdresDax
estat archlm, lags(1,5,10)
regress stdresSP500
estat archlm, lags(1,5,10)
regress stdresNikkei225
estat archlm, lags(1,5,10)
regress stdresFtse
estat archlm, lags(1,5,10)
sjlog close, replace

* DCC refined
sjlog using logs/DCCRefined, replace
mgarch dcc (Dax30 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (FTSE100 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1/2)) (Nikkei225 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1/2) garch(1)) (SP500 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1/2)), nolog
estimates store	DCCRefined1
sjlog close, replace

sjlog using logs/LRTest_DCC2, replace
lrtest DCC DCCRefined1
estimates stats DCC DCCRefined1
sjlog close, replace

sjlog using logs/DCCRefined2, replace
mgarch dcc (Dax30 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (FTSE100 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (Nikkei225 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (SP500 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1/2)), nolog
estimates store	DCCRefined2
sjlog close, replace

sjlog using logs/LRTest_DCC3, replace
lrtest DCC DCCRefined2
estimates stats DCC DCCRefined1 DCCRefined2
sjlog close, replace

* DCC Tse & Tsui
sjlog using logs/DCCT, replace
mgarch vcc (Dax30 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (FTSE100 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (Nikkei225 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (SP500 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1/2)), nolog
estimates store DCCT_Gaussian			
sjlog close, replace

sjlog using logs/VariancesDCCT, replace
predict H_DCCT*, variance
tsset date
tsline H_DCCT_Dax30_Dax30, tlabel(, format(%tdccYY)) name(VolDCCTDax30)
tsline H_DCCT_FTSE100_FTSE100, tlabel(, format(%tdccYY)) name(VolDCCTFTSE100)
tsline H_DCCT_Nikkei225_Nikkei225, tlabel(, format(%tdccYY)) name(VolDCCTNikkei225)
tsline H_DCCT_SP500_SP500, tlabel(, format(%tdccYY)) name(VolDCCTSP500)
graph combine VolDCCTDax30 VolDCCTFTSE100 VolDCCTNikkei225 VolDCCTSP500
sjlog close, replace
graph export eps/VariancesDCCT.eps, replace
graph export svg/VariancesDCCT.svg, replace

sjlog using logs/CorrelationsDCCT, replace
predict corr_DCCT*, correlation
tsline corr_DCCT_FTSE100_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdcctftsedax)
tsline corr_DCCT_Nikkei225_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdcctnikkeidax)
tsline corr_DCCT_SP500_Dax30, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdcctspdax)
tsline corr_DCCT_Nikkei225_FTSE100, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdcctnikkeiftse)
tsline corr_DCCT_SP500_FTSE100, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdcctspftse)
tsline corr_DCCT_SP500_Nikkei225, ylabel(0(.2)1) tlabel(, format(%tdccYY)) name(corrdcctspnikkei)
graph combine corrdcctftsedax corrdcctnikkeidax corrdcctspdax corrdcctnikkeiftse corrdcctspftse corrdcctspnikkei
sjlog close, replace
graph export eps/CorrelationsDCCT.eps, replace
graph export svg/CorrelationsDCCt.svg, replace

* DCC Tse and Tsui with Student-t distribution
sjlog using logs/StartingValues, replace
tsset newdate
matrix parameters=[e(b),30]
sjlog close, replace

sjlog using logs/DCCTStudent, replace
mgarch vcc (Dax30 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (FTSE100 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (Nikkei225 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1)) (SP500 = L.Dax30 L.FTSE100 L.SP500 L.Nikkei225, arch(1) garch(1/2)), distribution(t) from(parameters) nolog
estimates store DCCT_StudentT			
sjlog close, replace

sjlog using logs/LRTest_DCC4, replace
lrtest DCCT_StudentT DCCT_Gaussian
estimates stats DCCT_Gaussian DCCT_StudentT
sjlog close, replace

* Forecast
sjlog using logs/DCCForecast, replace
tsset date
tsappend, add(100)
predict H_Forecast*, variance dynamic(mdy(12,30,2013))
tsline H_Forecast_SP500_SP500 H_Forecast_FTSE100_FTSE100 H_Forecast_Dax30_Dax30 H_Forecast_Nikkei225_Nikkei225 if date>=mdy(12,31,2011), tlabel(01jan2012 01jan2013 01jan2014 01jan2015, format(%tdnn/dd/ccYY)) tline(30dec2013) legend(rows(4))
sjlog close, replace
tsline H_Forecast_SP500_SP500 H_Forecast_FTSE100_FTSE100 H_Forecast_Dax30_Dax30 H_Forecast_Nikkei225_Nikkei225 if date>=mdy(12,31,2011), tlabel(01jan2012 01jan2013 01jan2014 01jan2015, format(%tdnn/dd/ccYY)) tline(30dec2013) legend(rows(4) size(small))
graph export eps/DCCVarianceForecast.eps, replace
graph export svg/DCCVarianceForecast.svg, replace
 
sjlog using logs/DCCForecastCorr, replace
predict corr_For*, correlation dynamic(mdy(12,30,2013))
tsline corr_For_SP500_Dax30 corr_For_SP500_FTSE100 corr_For_SP500_Nikkei225 if date >= mdy(12,31,2011), tlabel(01jan2012 01jan2013 01jan2014 01jan2015, format(%tdnn/dd/ccYY)) tline(30dec2013) legend(rows(3))
sjlog close, replace
graph export eps/DCCCorrelationForecast.eps, replace
graph export svg/DCCCorrelationForecast.svg, replace

